#line 2 "sequence/igl.c"

#line 4 "sequence/igl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ig_create_buffer
#define yy_delete_buffer ig_delete_buffer
#define yy_flex_debug ig_flex_debug
#define yy_init_buffer ig_init_buffer
#define yy_flush_buffer ig_flush_buffer
#define yy_load_buffer_state ig_load_buffer_state
#define yy_switch_to_buffer ig_switch_to_buffer
#define yyin igin
#define yyleng igleng
#define yylex iglex
#define yylineno iglineno
#define yyout igout
#define yyrestart igrestart
#define yytext igtext
#define yywrap igwrap
#define yyalloc igalloc
#define yyrealloc igrealloc
#define yyfree igfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE igrestart(igin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int igleng;

extern FILE *igin, *igout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up igtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up igtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via igrestart()), so that the user can continue scanning by
	 * just pointing igin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when igtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int igleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow igwrap()'s to do buffer switches
 * instead of setting up a fresh igin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void igrestart (FILE *input_file  );
void ig_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE ig_create_buffer (FILE *file,int size  );
void ig_delete_buffer (YY_BUFFER_STATE b  );
void ig_flush_buffer (YY_BUFFER_STATE b  );
void igpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void igpop_buffer_state (void );

static void igensure_buffer_stack (void );
static void ig_load_buffer_state (void );
static void ig_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER ig_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE ig_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE ig_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE ig_scan_bytes (yyconst char *bytes,int len  );

void *igalloc (yy_size_t  );
void *igrealloc (void *,yy_size_t  );
void igfree (void *  );

#define yy_new_buffer ig_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        igensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ig_create_buffer(igin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        igensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ig_create_buffer(igin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define igwrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *igin = (FILE *) 0, *igout = (FILE *) 0;

typedef int yy_state_type;

extern int iglineno;

int iglineno = 1;

extern char *igtext;
#define yytext_ptr igtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up igtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	igleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 20
#define YY_END_OF_BUFFER 21
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[349] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   21,   19,
       18,    1,   19,    4,    5,    7,   11,   10,    8,   17,
       13,   15,   12,   14,    2,    3,    4,    6,    7,    0,
        9,    8,   16,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,

        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,

        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,

        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    4,    7,   12,
        2,    4,    7,   12,    2,    4,    7,   12,    2,    4,
        7,   12,    2,    4,    7,   12,    2,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    5,    6,    1,    1,    7,    7,
        1,    1,    1,    1,    1,    1,    1,    1,    8,    1,
        1,    1,    1,    1,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        1,    1,    1,    1,    1,    1,    9,    9,    9,    9,

        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    1,    1,    1,   10,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[11] =
    {   0,
        1,    2,    3,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[590] =
    {   0,
      305,    0,  299,  298,    7,    9,   12,    0,  295,  906,
      906,  906,  291,    0,  280,    0,   21,  906,  285,  906,
      906,  273,   21,  906,    0,  906,    0,  906,    0,    0,
      906,    0,  906,   28,    0,    0,    0,   35,    0,    0,
        0,   42,    0,    0,    0,   49,    0,    0,    0,   56,
        0,    0,    0,   63,    0,    0,    0,   70,    0,    0,
        0,   77,    0,    0,    0,   84,    0,    0,    0,   91,
        0,    0,    0,   98,    0,    0,    0,  105,    0,    0,
        0,  112,    0,    0,    0,  119,    0,    0,    0,  126,
        0,    0,    0,  133,    0,    0,    0,  140,    0,    0,

        0,  147,    0,    0,    0,  154,    0,    0,    0,  161,
        0,    0,    0,  168,    0,    0,    0,  175,    0,    0,
        0,  182,    0,    0,    0,  189,    0,    0,    0,  196,
        0,    0,    0,  203,    0,    0,    0,  210,    0,    0,
        0,  217,    0,    0,    0,  224,    0,    0,    0,  231,
        0,    0,    0,  238,    0,    0,    0,  245,    0,    0,
        0,  252,    0,    0,    0,  259,    0,    0,    0,  266,
        0,    0,    0,  273,    0,    0,    0,  280,    0,    0,
        0,  287,    0,    0,    0,  294,    0,    0,    0,  301,
        0,    0,    0,  308,    0,    0,    0,  315,    0,    0,

        0,  322,    0,    0,    0,  329,    0,    0,    0,  336,
        0,    0,    0,  343,    0,    0,    0,  350,    0,    0,
        0,  357,    0,    0,    0,  364,    0,    0,    0,  371,
        0,    0,    0,  378,    0,    0,    0,  385,    0,    0,
        0,  392,    0,    0,    0,  399,    0,    0,    0,  406,
        0,    0,    0,  413,    0,    0,    0,  420,    0,    0,
        0,  427,    0,    0,    0,  434,    0,    0,    0,  441,
        0,    0,    0,  448,    0,    0,    0,  455,    0,    0,
        0,  462,    0,    0,    0,  469,    0,    0,    0,  476,
        0,    0,    0,  483,    0,    0,    0,  490,    0,    0,

        0,  497,    0,    0,    0,  504,    0,    0,    0,  511,
        0,    0,    0,  518,    0,    0,    0,  525,    0,    0,
        0,  532,    0,    0,    0,  539,    0,    0,    0,  546,
        0,    0,    0,  553,    0,    0,    0,  560,    0,    0,
        0,  567,    0,  906,  906,  906,  906,  906,  577,  580,
      583,  586,  589,  279,  591,  593,  273,  595,  597,  272,
      599,  601,  266,  603,  605,  265,  607,  609,  259,  611,
      613,  258,  615,  617,  252,  619,  621,  251,  623,  625,
      245,  627,  629,  244,  631,  633,  238,  635,  637,  237,
      639,  641,  231,  643,  645,  230,  647,  649,  224,  651,

      653,  223,  655,  657,  217,  659,  661,  216,  663,  665,
      210,  667,  669,  209,  671,  673,  203,  675,  677,  202,
      679,  681,  196,  683,  685,  195,  687,  689,  189,  691,
      693,  188,  695,  697,  182,  699,  701,  181,  703,  705,
      175,  707,  709,  174,  711,  713,  168,  715,  717,  167,
      719,  721,  161,  723,  725,  160,  727,  729,  154,  731,
      733,  153,  735,  737,  147,  739,  741,  146,  743,  745,
      140,  747,  749,  139,  751,  753,  133,  755,  757,  132,
      759,  761,  126,  763,  765,  125,  767,  769,  119,  771,
      773,  118,  775,  777,  112,  779,  781,  111,  783,  785,

      105,  787,  789,  104,  791,  793,   98,  795,  797,   97,
      799,  801,   91,  803,  805,   90,  807,  809,   84,  811,
      813,   83,  815,  817,   77,  819,  821,   76,  823,  825,
       70,  827,  829,   69,  831,  833,   63,  835,  837,   62,
      839,  841,   56,  843,  845,   55,  847,  849,   49,  851,
      853,   48,  855,  857,   42,  859,  861,   41,  863,  865,
       35,  867,  869,   34,  871,  873,   28,  875,  877,   27,
      879,  881,    6,  883,  885,    5,  887,  889,    4,  891,
      893,    3,  895,  897,    1,  899,  901,    0,  903
    } ;

static yyconst flex_int16_t yy_def[590] =
    {   0,
      349,  349,  350,  350,  351,  351,  348,    7,  348,  348,
      348,  348,  352,  353,  348,  354,  348,  348,   17,  348,
      348,  348,  348,  348,  355,  348,  356,  348,  357,   17,
      348,   19,  348,  348,  358,  359,  360,  348,  361,  362,
      363,  348,  364,  365,  366,  348,  367,  368,  369,  348,
      370,  371,  372,  348,  373,  374,  375,  348,  376,  377,
      378,  348,  379,  380,  381,  348,  382,  383,  384,  348,
      385,  386,  387,  348,  388,  389,  390,  348,  391,  392,
      393,  348,  394,  395,  396,  348,  397,  398,  399,  348,
      400,  401,  402,  348,  403,  404,  405,  348,  406,  407,

      408,  348,  409,  410,  411,  348,  412,  413,  414,  348,
      415,  416,  417,  348,  418,  419,  420,  348,  421,  422,
      423,  348,  424,  425,  426,  348,  427,  428,  429,  348,
      430,  431,  432,  348,  433,  434,  435,  348,  436,  437,
      438,  348,  439,  440,  441,  348,  442,  443,  444,  348,
      445,  446,  447,  348,  448,  449,  450,  348,  451,  452,
      453,  348,  454,  455,  456,  348,  457,  458,  459,  348,
      460,  461,  462,  348,  463,  464,  465,  348,  466,  467,
      468,  348,  469,  470,  471,  348,  472,  473,  474,  348,
      475,  476,  477,  348,  478,  479,  480,  348,  481,  482,

      483,  348,  484,  485,  486,  348,  487,  488,  489,  348,
      490,  491,  492,  348,  493,  494,  495,  348,  496,  497,
      498,  348,  499,  500,  501,  348,  502,  503,  504,  348,
      505,  506,  507,  348,  508,  509,  510,  348,  511,  512,
      513,  348,  514,  515,  516,  348,  517,  518,  519,  348,
      520,  521,  522,  348,  523,  524,  525,  348,  526,  527,
      528,  348,  529,  530,  531,  348,  532,  533,  534,  348,
      535,  536,  537,  348,  538,  539,  540,  348,  541,  542,
      543,  348,  544,  545,  546,  348,  547,  548,  549,  348,
      550,  551,  552,  348,  553,  554,  555,  348,  556,  557,

      558,  348,  559,  560,  561,  348,  562,  563,  564,  348,
      565,  566,  567,  348,  568,  569,  570,  348,  571,  572,
      573,  348,  574,  575,  576,  348,  577,  578,  579,  348,
      580,  581,  582,  348,  583,  584,  585,  348,  586,  587,
      588,  348,  589,  348,  348,  348,  348,    0,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,

      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,

      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348
    } ;

static yyconst flex_int16_t yy_nxt[917] =
    {   0,
      345,  341,   12,  337,  333,  329,  325,   13,   17,   18,
       19,   18,   20,   21,   22,   23,   23,   23,   24,   20,
       23,   23,   30,   31,   34,   34,   34,  321,  317,   34,
       34,   38,   38,   38,  313,  309,   38,   38,   42,   42,
       42,  305,  301,   42,   42,   46,   46,   46,  297,  293,
       46,   46,   50,   50,   50,  289,  285,   50,   50,   54,
       54,   54,  281,  277,   54,   54,   58,   58,   58,  273,
      269,   58,   58,   62,   62,   62,  265,  261,   62,   62,
       66,   66,   66,  257,  253,   66,   66,   70,   70,   70,
      249,  245,   70,   70,   74,   74,   74,  241,  237,   74,

       74,   78,   78,   78,  233,  229,   78,   78,   82,   82,
       82,  225,  221,   82,   82,   86,   86,   86,  217,  213,
       86,   86,   90,   90,   90,  209,  205,   90,   90,   94,
       94,   94,  201,  197,   94,   94,   98,   98,   98,  193,
      189,   98,   98,  102,  102,  102,  185,  181,  102,  102,
      106,  106,  106,  177,  173,  106,  106,  110,  110,  110,
      169,  165,  110,  110,  114,  114,  114,  161,  157,  114,
      114,  118,  118,  118,  153,  149,  118,  118,  122,  122,
      122,  145,  141,  122,  122,  126,  126,  126,  137,  133,
      126,  126,  130,  130,  130,  129,  125,  130,  130,  134,

      134,  134,  121,  117,  134,  134,  138,  138,  138,  113,
      109,  138,  138,  142,  142,  142,  105,  101,  142,  142,
      146,  146,  146,   97,   93,  146,  146,  150,  150,  150,
       89,   85,  150,  150,  154,  154,  154,   81,   77,  154,
      154,  158,  158,  158,   73,   69,  158,  158,  162,  162,
      162,   65,   61,  162,  162,  166,  166,  166,   57,   53,
      166,  166,  170,  170,  170,   49,   45,  170,  170,  174,
      174,  174,   41,   37,  174,  174,  178,  178,  178,   29,
       33,  178,  178,  182,  182,  182,   32,   28,  182,  182,
      186,  186,  186,   26,  348,  186,  186,  190,  190,  190,

       15,   15,  190,  190,  194,  194,  194,   11,  348,  194,
      194,  198,  198,  198,  348,  348,  198,  198,  202,  202,
      202,  348,  348,  202,  202,  206,  206,  206,  348,  348,
      206,  206,  210,  210,  210,  348,  348,  210,  210,  214,
      214,  214,  348,  348,  214,  214,  218,  218,  218,  348,
      348,  218,  218,  222,  222,  222,  348,  348,  222,  222,
      226,  226,  226,  348,  348,  226,  226,  230,  230,  230,
      348,  348,  230,  230,  234,  234,  234,  348,  348,  234,
      234,  238,  238,  238,  348,  348,  238,  238,  242,  242,
      242,  348,  348,  242,  242,  246,  246,  246,  348,  348,

      246,  246,  250,  250,  250,  348,  348,  250,  250,  254,
      254,  254,  348,  348,  254,  254,  258,  258,  258,  348,
      348,  258,  258,  262,  262,  262,  348,  348,  262,  262,
      266,  266,  266,  348,  348,  266,  266,  270,  270,  270,
      348,  348,  270,  270,  274,  274,  274,  348,  348,  274,
      274,  278,  278,  278,  348,  348,  278,  278,  282,  282,
      282,  348,  348,  282,  282,  286,  286,  286,  348,  348,
      286,  286,  290,  290,  290,  348,  348,  290,  290,  294,
      294,  294,  348,  348,  294,  294,  298,  298,  298,  348,
      348,  298,  298,  302,  302,  302,  348,  348,  302,  302,

      306,  306,  306,  348,  348,  306,  306,  310,  310,  310,
      348,  348,  310,  310,  314,  314,  314,  348,  348,  314,
      314,  318,  318,  318,  348,  348,  318,  318,  322,  322,
      322,  348,  348,  322,  322,  326,  326,  326,  348,  348,
      326,  326,  330,  330,  330,  348,  348,  330,  330,  334,
      334,  334,  348,  348,  334,  334,  338,  338,  338,  348,
      348,  338,  338,  342,  342,  342,  348,  348,  342,  342,
      346,  346,  346,  348,  348,  346,  346,   10,   10,   10,
       14,   14,   14,   16,   16,   16,   25,   25,   25,   27,
       27,   35,   35,   36,   36,   39,   39,   40,   40,   43,

       43,   44,   44,   47,   47,   48,   48,   51,   51,   52,
       52,   55,   55,   56,   56,   59,   59,   60,   60,   63,
       63,   64,   64,   67,   67,   68,   68,   71,   71,   72,
       72,   75,   75,   76,   76,   79,   79,   80,   80,   83,
       83,   84,   84,   87,   87,   88,   88,   91,   91,   92,
       92,   95,   95,   96,   96,   99,   99,  100,  100,  103,
      103,  104,  104,  107,  107,  108,  108,  111,  111,  112,
      112,  115,  115,  116,  116,  119,  119,  120,  120,  123,
      123,  124,  124,  127,  127,  128,  128,  131,  131,  132,
      132,  135,  135,  136,  136,  139,  139,  140,  140,  143,

      143,  144,  144,  147,  147,  148,  148,  151,  151,  152,
      152,  155,  155,  156,  156,  159,  159,  160,  160,  163,
      163,  164,  164,  167,  167,  168,  168,  171,  171,  172,
      172,  175,  175,  176,  176,  179,  179,  180,  180,  183,
      183,  184,  184,  187,  187,  188,  188,  191,  191,  192,
      192,  195,  195,  196,  196,  199,  199,  200,  200,  203,
      203,  204,  204,  207,  207,  208,  208,  211,  211,  212,
      212,  215,  215,  216,  216,  219,  219,  220,  220,  223,
      223,  224,  224,  227,  227,  228,  228,  231,  231,  232,
      232,  235,  235,  236,  236,  239,  239,  240,  240,  243,

      243,  244,  244,  247,  247,  248,  248,  251,  251,  252,
      252,  255,  255,  256,  256,  259,  259,  260,  260,  263,
      263,  264,  264,  267,  267,  268,  268,  271,  271,  272,
      272,  275,  275,  276,  276,  279,  279,  280,  280,  283,
      283,  284,  284,  287,  287,  288,  288,  291,  291,  292,
      292,  295,  295,  296,  296,  299,  299,  300,  300,  303,
      303,  304,  304,  307,  307,  308,  308,  311,  311,  312,
      312,  315,  315,  316,  316,  319,  319,  320,  320,  323,
      323,  324,  324,  327,  327,  328,  328,  331,  331,  332,
      332,  335,  335,  336,  336,  339,  339,  340,  340,  343,

      343,  344,  344,  347,  347,    9,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348
    } ;

static yyconst flex_int16_t yy_chk[917] =
    {   0,
      588,  585,    2,  582,  579,  576,  573,    2,    5,    5,
        6,    6,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,   17,   17,   23,   23,   23,  570,  567,   23,
       23,   34,   34,   34,  564,  561,   34,   34,   38,   38,
       38,  558,  555,   38,   38,   42,   42,   42,  552,  549,
       42,   42,   46,   46,   46,  546,  543,   46,   46,   50,
       50,   50,  540,  537,   50,   50,   54,   54,   54,  534,
      531,   54,   54,   58,   58,   58,  528,  525,   58,   58,
       62,   62,   62,  522,  519,   62,   62,   66,   66,   66,
      516,  513,   66,   66,   70,   70,   70,  510,  507,   70,

       70,   74,   74,   74,  504,  501,   74,   74,   78,   78,
       78,  498,  495,   78,   78,   82,   82,   82,  492,  489,
       82,   82,   86,   86,   86,  486,  483,   86,   86,   90,
       90,   90,  480,  477,   90,   90,   94,   94,   94,  474,
      471,   94,   94,   98,   98,   98,  468,  465,   98,   98,
      102,  102,  102,  462,  459,  102,  102,  106,  106,  106,
      456,  453,  106,  106,  110,  110,  110,  450,  447,  110,
      110,  114,  114,  114,  444,  441,  114,  114,  118,  118,
      118,  438,  435,  118,  118,  122,  122,  122,  432,  429,
      122,  122,  126,  126,  126,  426,  423,  126,  126,  130,

      130,  130,  420,  417,  130,  130,  134,  134,  134,  414,
      411,  134,  134,  138,  138,  138,  408,  405,  138,  138,
      142,  142,  142,  402,  399,  142,  142,  146,  146,  146,
      396,  393,  146,  146,  150,  150,  150,  390,  387,  150,
      150,  154,  154,  154,  384,  381,  154,  154,  158,  158,
      158,  378,  375,  158,  158,  162,  162,  162,  372,  369,
      162,  162,  166,  166,  166,  366,  363,  166,  166,  170,
      170,  170,  360,  357,  170,  170,  174,  174,  174,  354,
       22,  174,  174,  178,  178,  178,   19,   15,  178,  178,
      182,  182,  182,   13,    9,  182,  182,  186,  186,  186,

        4,    3,  186,  186,  190,  190,  190,    1,    0,  190,
      190,  194,  194,  194,    0,    0,  194,  194,  198,  198,
      198,    0,    0,  198,  198,  202,  202,  202,    0,    0,
      202,  202,  206,  206,  206,    0,    0,  206,  206,  210,
      210,  210,    0,    0,  210,  210,  214,  214,  214,    0,
        0,  214,  214,  218,  218,  218,    0,    0,  218,  218,
      222,  222,  222,    0,    0,  222,  222,  226,  226,  226,
        0,    0,  226,  226,  230,  230,  230,    0,    0,  230,
      230,  234,  234,  234,    0,    0,  234,  234,  238,  238,
      238,    0,    0,  238,  238,  242,  242,  242,    0,    0,

      242,  242,  246,  246,  246,    0,    0,  246,  246,  250,
      250,  250,    0,    0,  250,  250,  254,  254,  254,    0,
        0,  254,  254,  258,  258,  258,    0,    0,  258,  258,
      262,  262,  262,    0,    0,  262,  262,  266,  266,  266,
        0,    0,  266,  266,  270,  270,  270,    0,    0,  270,
      270,  274,  274,  274,    0,    0,  274,  274,  278,  278,
      278,    0,    0,  278,  278,  282,  282,  282,    0,    0,
      282,  282,  286,  286,  286,    0,    0,  286,  286,  290,
      290,  290,    0,    0,  290,  290,  294,  294,  294,    0,
        0,  294,  294,  298,  298,  298,    0,    0,  298,  298,

      302,  302,  302,    0,    0,  302,  302,  306,  306,  306,
        0,    0,  306,  306,  310,  310,  310,    0,    0,  310,
      310,  314,  314,  314,    0,    0,  314,  314,  318,  318,
      318,    0,    0,  318,  318,  322,  322,  322,    0,    0,
      322,  322,  326,  326,  326,    0,    0,  326,  326,  330,
      330,  330,    0,    0,  330,  330,  334,  334,  334,    0,
        0,  334,  334,  338,  338,  338,    0,    0,  338,  338,
      342,  342,  342,    0,    0,  342,  342,  349,  349,  349,
      350,  350,  350,  351,  351,  351,  352,  352,  352,  353,
      353,  355,  355,  356,  356,  358,  358,  359,  359,  361,

      361,  362,  362,  364,  364,  365,  365,  367,  367,  368,
      368,  370,  370,  371,  371,  373,  373,  374,  374,  376,
      376,  377,  377,  379,  379,  380,  380,  382,  382,  383,
      383,  385,  385,  386,  386,  388,  388,  389,  389,  391,
      391,  392,  392,  394,  394,  395,  395,  397,  397,  398,
      398,  400,  400,  401,  401,  403,  403,  404,  404,  406,
      406,  407,  407,  409,  409,  410,  410,  412,  412,  413,
      413,  415,  415,  416,  416,  418,  418,  419,  419,  421,
      421,  422,  422,  424,  424,  425,  425,  427,  427,  428,
      428,  430,  430,  431,  431,  433,  433,  434,  434,  436,

      436,  437,  437,  439,  439,  440,  440,  442,  442,  443,
      443,  445,  445,  446,  446,  448,  448,  449,  449,  451,
      451,  452,  452,  454,  454,  455,  455,  457,  457,  458,
      458,  460,  460,  461,  461,  463,  463,  464,  464,  466,
      466,  467,  467,  469,  469,  470,  470,  472,  472,  473,
      473,  475,  475,  476,  476,  478,  478,  479,  479,  481,
      481,  482,  482,  484,  484,  485,  485,  487,  487,  488,
      488,  490,  490,  491,  491,  493,  493,  494,  494,  496,
      496,  497,  497,  499,  499,  500,  500,  502,  502,  503,
      503,  505,  505,  506,  506,  508,  508,  509,  509,  511,

      511,  512,  512,  514,  514,  515,  515,  517,  517,  518,
      518,  520,  520,  521,  521,  523,  523,  524,  524,  526,
      526,  527,  527,  529,  529,  530,  530,  532,  532,  533,
      533,  535,  535,  536,  536,  538,  538,  539,  539,  541,
      541,  542,  542,  544,  544,  545,  545,  547,  547,  548,
      548,  550,  550,  551,  551,  553,  553,  554,  554,  556,
      556,  557,  557,  559,  559,  560,  560,  562,  562,  563,
      563,  565,  565,  566,  566,  568,  568,  569,  569,  571,
      571,  572,  572,  574,  574,  575,  575,  577,  577,  578,
      578,  580,  580,  581,  581,  583,  583,  584,  584,  586,

      586,  587,  587,  589,  589,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int ig_flex_debug;
int ig_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *igtext;
#line 1 "sequence/igl.l"
/* igl.l - IG sequence lexer */
#line 4 "sequence/igl.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif

#include "sequence/igy.h"
#define YY_NO_INPUT 1

#line 857 "sequence/igl.c"

#define INITIAL 0
#define HCOM 1
#define HNAM 2
#define SEQS 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int iglex_destroy (void );

int igget_debug (void );

void igset_debug (int debug_flag  );

YY_EXTRA_TYPE igget_extra (void );

void igset_extra (YY_EXTRA_TYPE user_defined  );

FILE *igget_in (void );

void igset_in  (FILE * _in_str  );

FILE *igget_out (void );

void igset_out  (FILE * _out_str  );

int igget_leng (void );

char *igget_text (void );

int igget_lineno (void );

void igset_lineno (int _line_number  );

YYSTYPE * igget_lval (void );

void igset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int igwrap (void );
#else
extern int igwrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( igtext, igleng, 1, igout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( igin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( igin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, igin))==0 && ferror(igin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(igin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int iglex \
               (YYSTYPE * yylval_param );

#define YY_DECL int iglex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after igtext and igleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( igleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(igtext[igleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 39 "sequence/igl.l"


#line 1058 "sequence/igl.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! igin )
			igin = stdin;

		if ( ! igout )
			igout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			igensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				ig_create_buffer(igin,YY_BUF_SIZE );
		}

		ig_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of igtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 349 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 348 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 41 "sequence/igl.l"
; /* Empty lines ignored */
	YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up igtext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up igtext again */
YY_RULE_SETUP
#line 43 "sequence/igl.l"
{ BEGIN HCOM; return SEM; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up igtext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up igtext again */
YY_RULE_SETUP
#line 44 "sequence/igl.l"
{ BEGIN HCOM; return SEM; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 45 "sequence/igl.l"
{ yylval->str = strdup(igtext); return TXT; }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 46 "sequence/igl.l"
{ BEGIN HNAM; return EOL; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up igtext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up igtext again */
YY_RULE_SETUP
#line 47 "sequence/igl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 49 "sequence/igl.l"
{ yylval->str = strdup(igtext); return NAM; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 50 "sequence/igl.l"
; /* Leading spaces ignored */
	YY_BREAK
case 9:
/* rule 9 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up igtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up igtext again */
YY_RULE_SETUP
#line 51 "sequence/igl.l"
; /* Trailing spaces ignored */
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 52 "sequence/igl.l"
{ BEGIN SEQS; return EOL; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 53 "sequence/igl.l"
{ return ERR; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 55 "sequence/igl.l"
{ yylval->str = strdup(igtext); return BAS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 56 "sequence/igl.l"
; /* Spaces ignored */
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 57 "sequence/igl.l"
{ return TYP; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 58 "sequence/igl.l"
; /* Newlines ignored */
	YY_BREAK
case 16:
/* rule 16 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up igtext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up igtext again */
YY_RULE_SETUP
#line 59 "sequence/igl.l"
{ BEGIN INITIAL; return END; }
	YY_BREAK
case YY_STATE_EOF(SEQS):
#line 60 "sequence/igl.l"
{ BEGIN INITIAL; return END; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 61 "sequence/igl.l"
{ return ERR; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HCOM):
case YY_STATE_EOF(HNAM):
#line 63 "sequence/igl.l"
{ BEGIN INITIAL; return NUL; }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 64 "sequence/igl.l"
{ return ERR; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 65 "sequence/igl.l"
{ return ERR; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 67 "sequence/igl.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1274 "sequence/igl.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed igin at a new source and called
			 * iglex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = igin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( igwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * igtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of iglex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					igrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			igrestart(igin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) igrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 349 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 349 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 348);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					igrestart(igin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( igwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve igtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void igrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        igensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            ig_create_buffer(igin,YY_BUF_SIZE );
	}

	ig_init_buffer(YY_CURRENT_BUFFER,input_file );
	ig_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void ig_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		igpop_buffer_state();
	 *		igpush_buffer_state(new_buffer);
     */
	igensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	ig_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (igwrap()) processing, but the only time this flag
	 * is looked at is after igwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void ig_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	igin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE ig_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) igalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ig_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) igalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in ig_create_buffer()" );

	b->yy_is_our_buffer = 1;

	ig_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with ig_create_buffer()
 * 
 */
    void ig_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		igfree((void *) b->yy_ch_buf  );

	igfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a igrestart() or at EOF.
 */
    static void ig_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	ig_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then ig_init_buffer was _probably_
     * called from igrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void ig_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		ig_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void igpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	igensure_buffer_stack();

	/* This block is copied from ig_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from ig_switch_to_buffer. */
	ig_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void igpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	ig_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		ig_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void igensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)igalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in igensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)igrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in igensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE ig_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) igalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ig_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	ig_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to iglex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       ig_scan_bytes() instead.
 */
YY_BUFFER_STATE ig_scan_string (yyconst char * yystr )
{
    
	return ig_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to iglex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE ig_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) igalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in ig_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = ig_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in ig_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up igtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		igtext[igleng] = (yy_hold_char); \
		(yy_c_buf_p) = igtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		igleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int igget_lineno  (void)
{
        
    return iglineno;
}

/** Get the input stream.
 * 
 */
FILE *igget_in  (void)
{
        return igin;
}

/** Get the output stream.
 * 
 */
FILE *igget_out  (void)
{
        return igout;
}

/** Get the length of the current token.
 * 
 */
int igget_leng  (void)
{
        return igleng;
}

/** Get the current token.
 * 
 */

char *igget_text  (void)
{
        return igtext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void igset_lineno (int  _line_number )
{
    
    iglineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see ig_switch_to_buffer
 */
void igset_in (FILE *  _in_str )
{
        igin = _in_str ;
}

void igset_out (FILE *  _out_str )
{
        igout = _out_str ;
}

int igget_debug  (void)
{
        return ig_flex_debug;
}

void igset_debug (int  _bdebug )
{
        ig_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from iglex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    igin = stdin;
    igout = stdout;
#else
    igin = (FILE *) 0;
    igout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * iglex_init()
     */
    return 0;
}

/* iglex_destroy is for both reentrant and non-reentrant scanners. */
int iglex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		ig_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		igpop_buffer_state();
	}

	/* Destroy the stack itself. */
	igfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * iglex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *igalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *igrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void igfree (void * ptr )
{
	free( (char *) ptr );	/* see igrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 67 "sequence/igl.l"



